@@ -8,6 +8,7 @@ import os
 import threading
 from random import randrange
 from time import sleep, time
+import cv2
 from PyQt5.QtCore import pyqtProperty, pyqtSlot, pyqtSignal
 from PyQt5.QtQuick import QQuickItem
 from pyffmpeg import FFmpeg
@@ -23,6 +24,8 @@ class QVideo(QQuickItem):
     def __init__(self, parent=None):
         super().__init__(parent)
         self.convert_folder = self.fix_splashes(os.environ['TEMP']) + '/soloman/converts'
+        self.temp_folder = self.convert_folder + '/temp'
+        os.makedirs(self.temp_folder)
         self._same_session = False
         # Video
         self._source = ''
@@ -40,6 +43,10 @@ class QVideo(QQuickItem):
         self._start_time = 0
         self._total_time = 0
         self._total_elapsed_time = 0.0
+        # Opencv
+        self._cv2_frames_len = 0
+        self._cv2_tmp_frames_len = 0
+        self._cv2_session = False
 
     frameUpdate = pyqtSignal(str, arguments=['updateFrame'])
     destroyed = pyqtSignal()
@@ -58,7 +65,6 @@ class QVideo(QQuickItem):
     def _updater(self):
 
         #conts = os.listdir(self.folder)
-        stills = self._stills_content
 
         # if user has called the stop or pause function
         # we will need to reset it in order to restart play
@@ -69,11 +75,11 @@ class QVideo(QQuickItem):
         self.setTime()
         self.setFrameNo()
 
-        while not self._stopped and self._frame_no != len(stills):
-            
+        while not self._stopped and self._frame_no != len(self._stills_content):
+
             #t1 = time()
             if not self._paused:
-                self._current_frame = 'file:///' + self.folder + '/' + stills[self._frame_no]
+                self._current_frame = 'file:///' + self.folder + '/' + self._stills_content[self._frame_no]
                 self.updateFrame('')
                 sleep(1/24)
             else:
@@ -197,7 +203,7 @@ class QVideo(QQuickItem):
         u_thread = threading.Thread(target = self._seek, args=[seconds])
         u_thread.daemon = True
         u_thread.start()
-    
+
     def _seek(self, seconds):
         self._frame_no = self._fps * seconds
 
@@ -261,5 +267,92 @@ class QVideo(QQuickItem):
             micro = round(tm, 2) * 1000 # this convert to microseconds
             self._total_elapsed_time = micro
 
+    def start_cv2(self):
+        if os.path.exists(self.convert_folder):
+            fold_len = len(os.listdir(self.convert_folder)) + 1
+        else:
+            fold_len = 1
+        self.folder = self.convert_folder + "/" + str(fold_len)
+        os.makedirs(self.folder)
+        self.cv2_updater()
+
+    def make_cv2_frame(self, frame):
+        c_thread = threading.Thread(target=self._make_cv2_frame, args=[frame])
+        c_thread.daemon = True
+        c_thread.start()
+
+    def _make_cv2_frame(self, frame):
+        # create the frame image
+        self._cv2_frames_len += 1
+        filename = self.folder + "/" + str(self._cv2_frames_len) + ".jpg"
+        cv2.imwrite(filename, frame)
+
+    def _make_temp_cv2_frame(self, frame):
+        # create the frame image
+        self._cv2_tmp_frames_len += 1
+        filename = self.temp_folder + "/" + str(self._cv2_tmp_frames_len) + ".jpg"
+        cv2.imwrite(filename, frame)
+        return filename
+
+    def show_cv2_frame(self, frame):
+        c_thread = threading.Thread(target=self._show_cv2_frame, args=[frame])
+        c_thread.daemon = True
+        c_thread.start()
+
+    def _show_cv2_frame(self, frame):
+        name = self._make_temp_cv2_frame(frame)
+        self._current_frame = 'file:///' + name
+        self.updateFrame('')
+
+    def cv2_updater(self):
+        # Avoid multiple playing instances
+        self._stopped = True
+        self._frame_no = 0
+        sleep(0.5)
+
+        u_thread = threading.Thread(target = self._cv2_updater)
+        u_thread.daemon = True
+        u_thread.start()
+
+    def _cv2_updater(self):
+        """
+        The updater for cv2
+        """
+
+        # if user has called the stop or pause function
+        # we will need to reset it in order to restart play
+        self._stopped = False
+        self._paused = False
+
+        self._start_time = time()  # set the universal start time
+        self.setTime()
+        self.setFrameNo()
+
+        # if no show frame has been called sleep and loop
+        while self._cv2_frames_len == 0:
+            sleep(1/3)
+
+        # Avoid showing frame 0
+        if self._frame_no == 0:
+            self._frame_no += 1
+
+        while not self._stopped and self._frame_no <= self._cv2_frames_len:
+
+            if not self._paused:
+                self._current_frame = 'file:///' + self.folder + '/' + str(self._frame_no) + ".jpg"
+                self.updateFrame('')
+                sleep(1/24)
+            else:
+                sleep(1/10)
+
+
+        # stop showing the last frame
+        self._current_frame = ''
+        self.updateFrame('')
+        
+        self._stopped = True  # stop all other processs; will cause no trouble
+        self._cv2_session = False
+
+
     def updateFrame(self, frame):
         self.frameUpdate.emit(frame)
